@@ -2,7 +2,7 @@
 -----------------------------------------------------------------------------
 --
 -- Module      :  IDE.Metainfo.SourceCollectorH
--- Copyright   :  2007-2010 Juergen Nicklisch-Franken, Hamish Mackenzie
+-- Copyright   :  2007-2011 Juergen Nicklisch-Franken, Hamish Mackenzie
 -- License     :  GPL
 --
 -- Maintainer  :  maintainer@leksah.org
@@ -57,14 +57,14 @@ import qualified Distribution.InstalledPackageInfo as IPI
 import IDE.StrippedPrefs (getUnpackDirectory, Prefs(..))
 import IDE.Metainfo.SourceDB (sourceForPackage, getSourcesMap)
 import MonadUtils (liftIO)
-import System.Directory (setCurrentDirectory, doesDirectoryExist,createDirectory,canonicalizePath)
+import System.Directory (setCurrentDirectory, doesDirectoryExist,createDirectory)
 import System.FilePath ((<.>), dropFileName, (</>))
 import Data.Maybe(mapMaybe)
 import IDE.Utils.GHCUtils (inGhcIO)
 import qualified Control.Exception as NewException (SomeException, catch)
 import IDE.Utils.Tool
 import Control.Monad (unless)
-import IDE.Utils.FileUtils(figureOutHaddockOpts)
+import IDE.Utils.FileUtils (figureOutGhcOpts, figureOutHaddockOpts,myCanonicalizePath)
 import Distribution.Package(PackageIdentifier)
 import GHC hiding(Id,Failed,Succeeded,ModuleName)
 import System.Log.Logger (warningM, debugM)
@@ -135,8 +135,8 @@ findSourceForPackage prefs packageConfig = do
 packageFromSource :: FilePath -> PackageConfig -> IO (Maybe PackageDescr, PackageCollectStats)
 packageFromSource cabalPath packageConfig = do
     setCurrentDirectory dirPath
-    ghcFlags <- figureOutHaddockOpts
-    debugM "leksah-server" ("ghcFlags:  " ++ show ghcFlags)
+    ghcFlags <- figureOutGhcOpts
+    debugM "leksah-server" ("ghcFlags:  " ++ show ghcFlags)	
     NewException.catch (inner ghcFlags) handler
     where
         _handler' (_e :: NewException.SomeException) = do
@@ -147,10 +147,14 @@ packageFromSource cabalPath packageConfig = do
             return (Nothing, PackageCollectStats packageName Nothing False False
                                             (Just ("Ghc failed to process: " ++ show e)))
         inner ghcFlags = inGhcIO ghcFlags [Opt_Haddock] $ \ _flags -> do
+#if MIN_VERSION_haddock(2,8,0)
+            (interfaces,_) <- processModules verbose (exportedMods ++ hiddenMods) [] []
+#else
             (interfaces,_) <- createInterfaces verbose (exportedMods ++ hiddenMods) [] []
+#endif
             liftIO $ print (length interfaces)
             let mods = map (interfaceToModuleDescr dirPath (getThisPackage packageConfig)) interfaces
-            sp <- liftIO $ canonicalizePath dirPath
+            sp <- liftIO $ myCanonicalizePath dirPath
             let pd = PackageDescr {
                     pdPackage           =   getThisPackage packageConfig
                 ,   pdModules           =   mods
