@@ -2,7 +2,7 @@
 -----------------------------------------------------------------------------
 --
 -- Module      :  IDE.Metainfo.WorkspaceCollector
--- Copyright   :  2007-2010 Juergen Nicklisch-Franken, Hamish Mackenzie
+-- Copyright   :  2007-2011 Juergen Nicklisch-Franken, Hamish Mackenzie
 -- License     :  GPL
 --
 -- Maintainer  :  maintainer@leksah.org
@@ -58,7 +58,7 @@ import GHC.Exception
 import MyMissing(forceHead)
 import LoadIface(findAndReadIface)
 import Distribution.Text(display)
-import TcRnMonad hiding (liftIO,MonadIO,LIE)
+import TcRnMonad (initTcRnIf, IfGblEnv(..))
 import qualified Maybes as M
 import IDE.Metainfo.InterfaceCollector
 import Data.Maybe
@@ -101,7 +101,7 @@ type NSig  = Located (Sig RdrName)
 -- | Test
 collectWorkspace :: PackageIdentifier ->  [(String,FilePath)] -> Bool -> Bool -> FilePath -> IO()
 collectWorkspace packId moduleList forceRebuild writeAscii dir = do
-    debugM "leksah-server" $ "collectWorkspace called with " ++ show moduleList
+    debugM "leksah-server" $ "collectWorkspace called with modules " ++ show moduleList ++ " in folder " ++ dir
     collectorPath <- liftIO $ getCollectorPath
     let packageCollectorPath = collectorPath </> packageIdentifierToString packId
     when forceRebuild $ do
@@ -110,9 +110,11 @@ collectWorkspace packId moduleList forceRebuild writeAscii dir = do
     -- Construct directory
     liftIO $ createDirectoryIfMissing True packageCollectorPath
     setCurrentDirectory dir
-    opts <- figureOutHaddockOpts -- figureOutGhcOpts
-    debugM "leksah-server" $ "before collect modules"
-    mapM_ (collectModule packageCollectorPath writeAscii packId opts) moduleList
+    opts1 <- figureOutGhcOpts
+    opts2 <- figureOutHaddockOpts
+
+    debugM "leksah-server" $ ("before collect modules" ++ "\n\nopts1: " ++ show opts1 ++ "\n\n opt2: " ++ show opts2)
+    mapM_ (collectModule packageCollectorPath writeAscii packId opts1) moduleList
     debugM "leksah-server" $ "after collect modules"
 
 collectModule :: FilePath -> Bool -> PackageIdentifier -> [String] -> (String,FilePath) -> IO()
@@ -141,7 +143,7 @@ collectModule collectorPackagePath writeAscii packId opts (modId,sourcePath) = d
 
 collectModule' :: FilePath -> FilePath -> Bool -> PackageIdentifier -> [String] -> ModuleName -> IO()
 collectModule' sourcePath destPath writeAscii packId opts moduleName' = gcatch (
-    inGhcIO opts [Opt_Haddock,Opt_Cpp] $ \ _dynFlags -> do
+    inGhcIO (opts++["-cpp"]) [Opt_Haddock] $ \ _dynFlags -> do
         session         <-  getSession
         (dynFlags3,fp') <-  preprocess session (sourcePath,Nothing)
         mbInterfaceDescr <- mayGetInterfaceDescription packId moduleName'
@@ -505,7 +507,6 @@ extractConstructor decl@(L loc (ConDecl {con_name = name, con_doc = doc})) =
             Just (L _ d) -> Just (BS.pack (printHsDoc d)))
         True
 
-
 extractRecordFields :: Located (ConDecl RdrName) -> [SimpleDescr]
 extractRecordFields (L _ _decl@(ConDecl {con_details = RecCon flds})) =
     map extractRecordFields' flds
@@ -610,7 +611,7 @@ mayGetInterfaceDescription pid mn = do
     mbIf <- mayGetInterfaceFile pid mn
     case mbIf of
         Nothing -> do
-            liftIO $ infoM "leksah-server" ("no interface file for " ++ show mn)
+            liftIO $ debugM "leksah-server" ("no interface file for " ++ show mn)
             return Nothing
         Just (mif,_) ->
             let allDescrs  =    extractExportedDescrH pid mif
