@@ -41,9 +41,15 @@ import Control.Concurrent
 import Control.Monad (unless, when)
 import Data.List (stripPrefix)
 import Data.Maybe (isJust, catMaybes)
+#ifdef MIN_VERSION_process_leksah
 import IDE.System.Process
        (proc, waitForProcess, ProcessHandle, createProcess, CreateProcess(..))
 import IDE.System.Process.Internals (StdStream(..))
+#else
+import System.Process
+       (proc, waitForProcess, ProcessHandle, createProcess, CreateProcess(..))
+import System.Process.Internals (StdStream(..))
+#endif
 import Control.DeepSeq
 import System.Log.Logger (debugM, criticalM)
 import System.Exit (ExitCode(..))
@@ -281,18 +287,20 @@ stripMarker s =
 
 ghciStripExpectedError :: String -> Maybe (Int, String)
 ghciStripExpectedError output =
-    case stripPrefix "\n<interactive>:1:0" output of
+    case stripPrefix "\n<interactive>:1:" output of
         Just rest ->
-            case stripPrefix ": Not in scope: `"
-                (maybe rest id (stripPrefix "-28" rest)) of
-                Just rest2 ->
-                    case stripMarker rest2 of
-                        Just (n, rest3) ->
-                            case stripPrefix "'\n" rest3 of
-                                Just rest4 -> Just (n, rest4)
+            case span (/= ':') rest of
+                (cols, rest2) | cols == "0" || cols == "1" || cols == "0-28" || cols == "1-29" ->
+                    case stripPrefix ": Not in scope: `" rest2 of
+                        Just rest3 ->
+                            case stripMarker rest3 of
+                                Just (n, rest4) ->
+                                    case stripPrefix "'\n" rest4 of
+                                        Just rest5 -> Just (n, rest5)
+                                        Nothing -> Nothing
                                 Nothing -> Nothing
                         Nothing -> Nothing
-                Nothing -> Nothing
+                _ -> Nothing
         Nothing -> Nothing
 
 ghciIsExpectedOutput :: Int -> String -> Bool
@@ -424,7 +432,7 @@ newGhci buildFlags interactiveFlags startupOutputHandler = do
             ToolCommand (":set prompt " ++ ghciPrompt) startupOutputHandler
         debugM "leksah-server" $ "Working out GHCi options"
         forkIO $ do
-            (output, _) <- runTool "runhaskell" (["Setup","build","--with-ghc=leksahecho"] ++ buildFlags) Nothing
+            (output, _) <- runTool "cabal" (["build","--with-ghc=leksahecho"] ++ buildFlags) Nothing
             case catMaybes $ map (findMake . toolline) output of
                 options:_ -> do
                         let newOptions = filterUnwanted options
